@@ -1,17 +1,15 @@
 from django import forms
+from django.conf import settings
 from django.contrib import admin
-from django.db.models import get_app
 from django.utils.translation import gettext_lazy as _
-from django.core.exceptions import ImproperlyConfigured
 
 from dbtemplates.models import Template
 
 # Check if django-reversion is installed and use reversions' VersionAdmin
 # as the base admin class if yes
-try:
-    get_app('reversion')
+if 'reversion'in settings.INSTALLED_APPS:
     from reversion.admin import VersionAdmin as TemplateModelAdmin
-except ImproperlyConfigured:
+else:
     from django.contrib.admin import ModelAdmin as TemplateModelAdmin
 
 class TemplateAdminForm(forms.ModelForm):
@@ -39,8 +37,12 @@ class TemplateAdmin(TemplateModelAdmin):
             'classes': ('collapse',),
         }),
     )
-    list_display = ('name', 'creation_date', 'last_changed')
+    list_display = ('name', 'creation_date', 'last_changed', 'site_list')
     list_filter = ('sites',)
     search_fields = ('name', 'content')
 
+    def site_list(self, template):
+          return ", ".join([site.name for site in template.sites.all()])
+    site_list.short_description = _('sites')
+
 admin.site.register(Template, TemplateAdmin)
